package FDN::Images::PDF;

use strict;
use warnings;

use base 'Exporter';
our @EXPORT = qw (
	pdf_page_to_jpeg
	explode_pdf_file
);


my $pdftk = `which pdftk`;
if ( ! $pdftk ) {
	die "I need pdftk";
}
chomp($pdftk);

my $pdfimages = `which pdfimages`;
if ( ! $pdfimages ) {
	die "I need pdfimages";
}
chomp($pdfimages);

my $convert = `which convert`;
if ( ! $convert ) {
	die "I need convert";
}
chomp($convert);

sub read_doc($) {
	my ( $doc ) = @_;
	local $/='';
	open IN, '<', $doc;
	my $data = <IN>;
	close IN;
	my @lines = split /\n/, $data;
	my $res = {};
	for my $l ( @lines ) {
		if ( $l !~ /^(\w+): (.*)$/ ) {
			die "Invalid line $l in $doc";
		}
		$res->{$1} = $2;
	}
	return $res;
}

my $global_count = 0;
sub pdf_page_to_jpeg($) {
	my ( $pdf ) = @_;
	print "  Je regarde la page $pdf...\n";
	$global_count++;
	my $prefix = sprintf "img_%04d", $global_count;
	`$pdfimages -j $pdf $prefix`;
	if ( -f $prefix.'-000.jpg' && ! -f $prefix.'-001.jpg' && ! -f $prefix.'-000.pbm' && ! -f $prefix.'-001.pbm' && ! -f $prefix.'-000.ppm' && ! -f $prefix.'-001.ppm' ) {
		print "     j'ai trouv une image non dforme, je prend.\n";
		rename $prefix.'-000.jpg', $prefix.'.jpg';
		return $prefix.'.jpg';
	}
	# Ok, c'est pas une image
	`rm -f $prefix-*`;
	print "     c'est pas une image, je converti.\n";
	`$convert -density 300 $pdf $prefix.jpg`;
	return $prefix.'.jpg';
}

sub explode_pdf_file($) {
	my ( $file ) = @_;

	print "Explode fichier $file\n";
	my $out = `$pdftk "$file" burst output page_%04d.pdf`;
	my $info = read_doc('doc_data.txt');
	my $num = $info->{'NumberOfPages'};
	print "  J'ai vu $num pages\n";
	my $res = [];
	for my $i ( 1 .. $num) {
		print "  Je regarde la page $i\n";
		my $page = sprintf "page_%04d.pdf", $i;
		if ( ! -f $page ) {
			print STDERR "File not found: $page\n";
			next;
		}
		my $image = pdf_page_to_jpeg($page);
		`rm -f $page`;
		push @$res, $image;
	}
	`rm -f doc_data.txt`;
	return $res;
}


1;
